package javax.xml.crypto;

import java.security.Key;
import javax.xml.crypto.dsig.keyinfo.KeyInfo;

public abstract class KeySelector
{
    protected KeySelector() {
    }
    
    public abstract KeySelectorResult select(KeyInfo p0, KeySelector.Purpose p1, AlgorithmMethod p2, XMLCryptoContext p3) throws KeySelectorException;
    
    public static KeySelector singletonKeySelector(Key key) {
        return new SingletonKeySelector(key);
    }
    
    public static class Purpose
    {
        private final String name;
        public static final KeySelector.Purpose SIGN;
        public static final KeySelector.Purpose VERIFY;
        public static final KeySelector.Purpose ENCRYPT;
        public static final KeySelector.Purpose DECRYPT;
        
        private Purpose(String name) {
            this.name = name;
        }
        
        @Override
        public String toString() {
            return this.name;
        }
        
        static {
            SIGN = new KeySelector.Purpose("sign");
            VERIFY = new KeySelector.Purpose("verify");
            ENCRYPT = new KeySelector.Purpose("encrypt");
            DECRYPT = new KeySelector.Purpose("decrypt");
        }
    }
    
    private static class SingletonKeySelector extends KeySelector
    {
        private final Key key;
        
        SingletonKeySelector(Key key) {
            if (key == null) {
                throw new NullPointerException();
            }
            this.key = key;
            return;
        }
        
        @Override
        public KeySelectorResult select(KeyInfo keyInfo, KeySelector.Purpose purpose, AlgorithmMethod algorithmMethod, XMLCryptoContext xmlCryptoContext) throws KeySelectorException {
            return new KeySelectorResult() {
                @Override
                public Key getKey() {
                    return KeySelector.SingletonKeySelector.this.key;
                }
            };
        }
    }
}
